/*
ndxscn.c - implementation of the elf_ndxscn(3) function.
Copyright (C) 1995 - 1998 Michael Riepe <michael@stud.uni-hannover.de>

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Library General Public
License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Library General Public License for more details.

You should have received a copy of the GNU Library General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include <private.h>

#ifndef lint
static const char rcsid[] = "@(#) $Id: ndxscn.c,v 1.3 1998/06/12 19:42:31 michael Exp $";
#endif /* lint */

size_t
elf_ndxscn(Elf_Scn *scn) {
    if (!scn) {
	return SHN_UNDEF;
    }
    elf_assert(scn->s_magic == SCN_MAGIC);
    return scn->s_index;
}
